@@ -27,6 +27,11 @@ if ($method === 'POST' && empty($action)) {
     $input = json_decode(file_get_contents('php://input'), true);
     if ($input && !empty($input['action'])) {
         $action = $input['action'];
+        
+        // If CSRF token is in JSON body, make it available for validation
+        if (isset($input['csrf_token']) && !isset($_POST['csrf_token'])) {
+            $_POST['csrf_token'] = $input['csrf_token'];
+        }
     }
 }
 
